# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""Rodent's brain MRI utilities."""
from .__about__ import (
    __version__,
    __copyright__,
    __credits__,
    __packagename__,
)

__all__ = [
    "__version__",
    "__copyright__",
    "__credits__",
    "__packagename__",
]
